From 12695337e9099eb0379dd300fb1f2555b46366fb Mon Sep 17 00:00:00 2001
From: "Xinwei Xiong(cubxxw-openim)" <3293172751nss@gmail.com>
Date: Tue, 4 Jul 2023 17:09:49 +0800
Subject: [PATCH] feat: add more feature in scripts

Signed-off-by: Xinwei Xiong(cubxxw-openim) <3293172751nss@gmail.com>
---
 .github/weekly-digest.yml       | 7 +++++++
 .github/workflows/openim-ci.yml | 4 ++--
 scripts/lib/release.sh          | 6 +++---
 scripts/make-rules/release.mk   | 2 +-
 scripts/make-rules/tools.mk     | 1 +
 5 files changed, 14 insertions(+), 6 deletions(-)
 create mode 100644 .github/weekly-digest.yml

diff --git a/.github/weekly-digest.yml b/.github/weekly-digest.yml
new file mode 100644
index 000000000..9deb72e7b
--- /dev/null
+++ b/.github/weekly-digest.yml
@@ -0,0 +1,7 @@
+# https://github.com/apps/weekly-digest/installations/new
+publishDay: sun
+canPublishIssues: true
+canPublishPullRequests: true
+canPublishContributors: true
+canPublishStargazers: true
+canPublishCommits: true
\ No newline at end of file
diff --git a/.github/workflows/openim-ci.yml b/.github/workflows/openim-ci.yml
index d58211444..c8b95eb8e 100644
--- a/.github/workflows/openim-ci.yml
+++ b/.github/workflows/openim-ci.yml
@@ -1,4 +1,4 @@
-name: OpenIMCI
+name: OpenIM CI
 
 on:
 # main branch
@@ -64,7 +64,7 @@ jobs:
       - name: Login to DockerHub
         uses: docker/login-action@v1
         with:
-          username: ${{ secrets.DOCKERHUB_USERNAME }}
+          username: ${{ env.DOCKERHUB_USERNAME }}
           password: ${{ secrets.DOCKERHUB_TOKEN }}
 
       - name: Build docker images for host arch and push images to registry
diff --git a/scripts/make-rules/release.mk b/scripts/make-rules/release.mk
index f3fd3d5f3..862aa3065 100644
--- a/scripts/make-rules/release.mk
+++ b/scripts/make-rules/release.mk
@@ -24,7 +24,7 @@ release.run: release.verify release.ensure-tag
 
 ## release.verify: Check if a tool is installed and install it
 .PHONY: release.verify
-release.verify: tools.verify.git-chglog tools.verify.github-release tools.verify.coscmd
+release.verify: tools.verify.git-chglog tools.verify.github-release tools.verify.coscmd tools.verify.coscli
 
 ## release.tag: release the project
 .PHONY: release.tag
diff --git a/scripts/make-rules/tools.mk b/scripts/make-rules/tools.mk
index c0e65ff94..468cf109f 100644
--- a/scripts/make-rules/tools.mk
+++ b/scripts/make-rules/tools.mk
@@ -133,6 +133,7 @@ install.github-release:
 ## install.coscli: Install coscli, used to upload files to cos
 # example: ./coscli  cp/sync -r  /home/off-line/docker-off-line/ cos://openim-1306374445/openim/image/amd/off-line/off-line/ -e cos.ap-guangzhou.myqcloud.com
 # https://cloud.tencent.com/document/product/436/71763
+# amd64
 .PHONY: install.coscli
 install.coscli:
 	@wget -q https://ghproxy.com/https://github.com/tencentyun/coscli/releases/download/v0.13.0-beta/coscli-linux -O ${TOOLS_DIR}/coscli
diff --git a/scripts/lib/release.sh b/scripts/lib/release.sh
index 1817e4ff2..e596afaff 100755
--- a/scripts/lib/release.sh
+++ b/scripts/lib/release.sh
@@ -27,8 +27,8 @@ readonly BUCKET="openim-1306374445"
 readonly REGION="ap-beijing"
 readonly COS_RELEASE_DIR="openim-release"
 
-# default cos command tool
-readonly COSTOOL="coscmd"
+# default cos command tool coscli or coscmd
+readonly COSTOOL="coscli"
 
 # This is where the final release artifacts are created locally
 readonly RELEASE_STAGE="${LOCAL_OUTPUT_ROOT}/release-stage"
@@ -37,7 +37,7 @@ readonly RELEASE_IMAGES="${LOCAL_OUTPUT_ROOT}/release-images"
 
 # OpenIM github account info
 readonly OPENIM_GITHUB_ORG=OpenIMSDK
-readonly OPENIM_GITHUB_REPO=openim
+readonly OPENIM_GITHUB_REPO=Open-IM-Server
 
 readonly ARTIFACT=openim.tar.gz
 readonly CHECKSUM=${ARTIFACT}.sha1sum